@@ -16,6 +16,8 @@ __all__ = [
     "Window",
 ]
 
+from typing import Any, Optional
+
 from java.lang import Object
 
 
@@ -40,6 +42,7 @@ class Color(Object):
     """
 
     def __init__(self, *args):
+        # type: (Any) -> None
         print(args)
 
 
@@ -57,7 +60,8 @@ class Container(Component):
     """
 
     def add(self, *args):
-        print(self, args)
+        # type: (Any) -> Optional[Component]
+        pass
 
 
 class Image(Object):
@@ -78,11 +82,17 @@ class Toolkit(Object):
     components to particular native toolkit implementations.
     """
 
+    def __init__(self):
+        # type: () -> None
+        pass
+
     def beep(self):
+        # type: () -> None
         print(self, "Beep!")
 
     @staticmethod
     def getDefaultToolkit():
+        # type: () -> Toolkit
         return Toolkit()
 
 
