@@ -13,6 +13,8 @@ from __future__ import print_function
 
 __all__ = ["BufferedImage"]
 
+from typing import Any
+
 from java.awt import Image
 
 
@@ -32,4 +34,5 @@ class BufferedImage(Image):
     """
 
     def __init__(self, *args):
+        # type: (Any) -> None
         print(args)
