@@ -4,8 +4,13 @@ utility classes (a string tokenizer, a random-number generator, and a
 bit array).
 """
 
+from __future__ import print_function
+
 __all__ = ["Date", "EventObject", "Locale"]
 
+from typing import Optional
+
+from dev.thecesrom.utils.decorators import classproperty
 from java.lang import Object
 
 
@@ -15,15 +20,43 @@ class Date(Object):
     """
 
     def __init__(self, date=None):
+        # type: (Optional[long]) -> None
         print(self, date)
 
+    def __cmp__(self, other):
+        # type: (Date) -> bool
+        pass
+
+    def __ge__(self, other):
+        # type: (Date) -> bool
+        pass
+
+    def __gt__(self, other):
+        # type: (Date) -> bool
+        pass
+
+    def __lt__(self, other):
+        # type: (Date) -> bool
+        pass
+
     def after(self, when):
+        # type: (Date) -> bool
         pass
 
     def before(self, when):
+        # type: (Date) -> bool
         pass
 
     def compareTo(self, anotherDate):
+        # type: (Date) -> int
+        pass
+
+    def getTime(self):
+        # type: () -> long
+        pass
+
+    def setTime(self, time):
+        # type: (long) -> None
         pass
 
 
@@ -36,18 +69,16 @@ class EventObject(Object):
     Event in question initially occurred upon.
     """
 
+    source = None  # type: Object
+
     def __init__(self, source):
+        # type: (Object) -> None
         self.source = source
 
     def getSource(self):
         return self.source
 
 
-class ClassProperty(property):
-    def __get__(self, cls, owner):
-        return classmethod(self.fget).__get__(None, owner)()
-
-
 class Locale(Object):
     """A Locale object represents a specific geographical, political, or
     cultural region. An operation that requires a Locale to perform its
@@ -58,7 +89,12 @@ class Locale(Object):
     or culture.
     """
 
+    country = None  # type: Optional[str]
+    language = None  # type: str
+    variant = None  # type: Optional[str]
+
     def __init__(self, language, country=None, variant=None):
+        # type: (str, Optional[str], Optional[str]) -> None
         self.language = language
         self.country = country
         self.variant = variant
@@ -74,86 +110,107 @@ class Locale(Object):
             ret += "_{}".format(self.variant)
         return unicode(ret)
 
-    @ClassProperty
+    @classproperty
     def CANADA(self):
+        # type: () -> Locale
         return Locale("en", "CA")
 
-    @ClassProperty
+    @classproperty
     def CANADA_FRENCH(self):
+        # type: () -> Locale
         return Locale("fr", "CA")
 
-    @ClassProperty
+    @classproperty
     def CHINA(self):
+        # type: () -> Locale
         return Locale("zh", "CN")
 
-    @ClassProperty
+    @classproperty
     def CHINESE(self):
+        # type: () -> Locale
         return Locale("zh")
 
-    @ClassProperty
+    @classproperty
     def ENGLISH(self):
+        # type: () -> Locale
         return Locale("en")
 
-    @ClassProperty
+    @classproperty
     def FRANCE(self):
+        # type: () -> Locale
         return Locale("fr", "FR")
 
-    @ClassProperty
+    @classproperty
     def FRENCH(self):
+        # type: () -> Locale
         return Locale("fr")
 
-    @ClassProperty
+    @classproperty
     def GERMAN(self):
+        # type: () -> Locale
         return Locale("de")
 
-    @ClassProperty
+    @classproperty
     def GERMANY(self):
+        # type: () -> Locale
         return Locale("de", "DE")
 
-    @ClassProperty
+    @classproperty
     def ITALIAN(self):
+        # type: () -> Locale
         return Locale("it")
 
-    @ClassProperty
+    @classproperty
     def ITALY(self):
+        # type: () -> Locale
         return Locale("it", "IT")
 
-    @ClassProperty
+    @classproperty
     def JAPAN(self):
+        # type: () -> Locale
         return Locale("ja", "JP")
 
-    @ClassProperty
+    @classproperty
     def JAPANESE(self):
+        # type: () -> Locale
         return Locale("ja")
 
-    @ClassProperty
+    @classproperty
     def KOREA(self):
+        # type: () -> Locale
         return Locale("ko", "KR")
 
-    @ClassProperty
+    @classproperty
     def KOREAN(self):
+        # type: () -> Locale
         return Locale("ko")
 
-    @ClassProperty
+    @classproperty
     def PRC(self):
-        return self.CHINA
+        # type: () -> Locale
+        return Locale("zh", "CN")
 
-    @ClassProperty
+    @classproperty
     def SIMPLIFIED_CHINESE(self):
-        return self.CHINA
+        # type: () -> Locale
+        return Locale("zh", "CN")
 
-    @ClassProperty
+    @classproperty
     def TAIWAN(self):
+        # type: () -> Locale
         return Locale("zh", "TW")
 
-    @ClassProperty
+    @classproperty
     def TRADITIONAL_CHINESE(self):
+        # type: () -> Locale
         return Locale("zh", "TW")
 
-    @ClassProperty
+    @classproperty
     def UK(self):
+        # type: () -> Locale
         return Locale("en", "GB")
 
-    @ClassProperty
+    @classproperty
     def US(self):
+        # type: () -> Locale
         return Locale("en", "US")
