@@ -35,13 +35,13 @@ import os.path
 
 from typing import Any, Dict, List, Optional, Type, Union
 
-from com.inductiveautomation.ignition.common import BasicDataset
+from com.inductiveautomation.ignition.common import BasicDataset, Dataset
 from com.inductiveautomation.ignition.common.script.builtin import DatasetUtilities
+from java.lang import String
 from java.util import Date, Locale
 
 ColType = Union[Date, float, int, str, unicode]
 PyDataSet = DatasetUtilities.PyDataSet
-String = Union[str, unicode]
 
 
 def addColumn(
@@ -302,7 +302,7 @@ def exportCSV(filename, showHeaders, dataset):
 
 
 def exportExcel(filename, showHeaders, dataset, nullsEmpty=False):
-    # type: (String, bool, List[BasicDataset], Optional[bool]) -> String
+    # type: (String, bool, List[BasicDataset], bool) -> String
     """Exports the contents of a dataset as an Excel spreadsheet,
     prompting the user to save the file to disk.
 
@@ -326,7 +326,7 @@ def exportExcel(filename, showHeaders, dataset, nullsEmpty=False):
         by the user.
     """
     print(filename, showHeaders, dataset, nullsEmpty)
-    return os.path.expanduser(str("~"))
+    return os.path.expanduser("~")
 
 
 def exportHTML(filename, showHeaders, dataset, title):
@@ -468,7 +468,7 @@ def setValue(dataset, rowIndex, columnName, value):
 def sort(
     dataset,  # type: BasicDataset
     keyColumn,  # type: Union[String, int]
-    ascending=True,  # type: Optional[bool]
+    ascending=True,  # type: bool
 ):
     # type: (...) -> BasicDataset
     """Takes a dataset and returns a sorted version of dataset.
@@ -500,9 +500,9 @@ def sort(
 
 def toCSV(
     dataset,  # type: BasicDataset
-    showHeaders=True,  # type: Optional[bool]
-    forExport=False,  # type: Optional[bool]
-    localized=False,  # type: Optional[bool]
+    showHeaders=True,  # type: bool
+    forExport=False,  # type: bool
+    localized=False,  # type: bool
 ):
     # type: (...) -> String
     """Formats the contents of a dataset as CSV (comma separated
@@ -553,7 +553,7 @@ def toDataSet(*args):
 def toExcel(
     showHeaders,  # type: bool
     dataset,  # type: List[BasicDataset]
-    nullsEmpty=False,  # type: Optional[bool]
+    nullsEmpty=False,  # type: bool
     sheetNames=None,  # type: Optional[List[String]]
 ):
     # type: (...) -> Any
@@ -585,13 +585,13 @@ def toExcel(
 
 
 def toPyDataSet(dataset):
-    # type: (BasicDataset) -> PyDataSet
+    # type: (Dataset) -> PyDataSet
     """This function converts from a normal DataSet to a PyDataSet,
     which is a wrapper class which makes working with datasets more
     Python-esque.
 
     Args:
-        dataset: A DataSet object to convert into a PyDataSet.
+        dataset: A Dataset object to convert into a PyDataSet.
 
     Returns:
         The newly created PyDataSet.
