@@ -54,12 +54,11 @@ __all__ = [
 from datetime import datetime
 from time import localtime, mktime
 
-from typing import Optional, Union
+from typing import Optional
 
+from java.lang import String
 from java.util import Date, Locale
 
-String = Union[str, unicode]
-
 
 def _now():
     # type: () -> datetime
@@ -236,7 +235,7 @@ def format(date, format="yyyy-MM-dd HH:mm:ss"):
     Jan-Dec, MMMM will give you January-December.
 
     Note:
-        The functions above are based off the the Java class
+        The functions above are based off the Java class
         `SimpleDateFormat` internally. The functions will accept any
         valid format string for that class.
 
@@ -284,6 +283,7 @@ def format(date, format="yyyy-MM-dd HH:mm:ss"):
         "W",
         "{}".format(_date.isocalendar()[1] - _date.replace(day=1).isocalendar()[1] + 1),
     )
+
     _format = _format.replace("XXX", "{:03.0f}:00".format(getTimezoneOffset()))
     _format = _format.replace("XX", "{:03.0f}00".format(getTimezoneOffset()))
     _format = _format.replace("X", "{:03.0f}".format(getTimezoneOffset()))
