@@ -7,6 +7,47 @@ database.
 from __future__ import print_function
 
 __all__ = [
+    "ARRAY",
+    "BIGINT",
+    "BINARY",
+    "BIT",
+    "BLOB",
+    "BOOLEAN",
+    "CHAR",
+    "CLOB",
+    "DATALINK",
+    "DATE",
+    "DECIMAL",
+    "DISTINCT",
+    "DOUBLE",
+    "FLOAT",
+    "INTEGER",
+    "JAVA_OBJECT",
+    "LONGNVARCHAR",
+    "LONGVARBINARY",
+    "LONGVARCHAR",
+    "NCHAR",
+    "NCLOB",
+    "NULL",
+    "NUMERIC",
+    "NVARCHAR",
+    "ORACLE_CURSOR",
+    "OTHER",
+    "READ_COMMITTED",
+    "READ_UNCOMMITTED",
+    "REAL",
+    "REF",
+    "REPEATABLE_READ",
+    "ROWID",
+    "SERIALIZABLE",
+    "SMALLINT",
+    "SQLXML",
+    "STRUCT",
+    "TIME",
+    "TIMESTAMP",
+    "TINYINT",
+    "VARBINARY",
+    "VARCHAR",
     "addDatasource",
     "beginNamedQueryTransaction",
     "beginTransaction",
@@ -37,18 +78,19 @@ __all__ = [
     "setDatasourceMaxConnections",
 ]
 
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional
 
 from com.inductiveautomation.ignition.common import BasicDataset
 from com.inductiveautomation.ignition.common.script.builtin import (
     DatasetUtilities,
     SProcCall,
 )
+from java.lang import String
 from java.util import Date
 from javax.swing import JComponent
 
 PyDataSet = DatasetUtilities.PyDataSet
-String = Union[str, unicode]
+
 
 # Type codes
 # These are codes defined by the JDBC specification.
@@ -102,13 +144,13 @@ SERIALIZABLE = 8
 def addDatasource(
     jdbcDriver,  # type: String
     name,  # type: String
-    description="",  # type: Optional[String]
+    description="",  # type: String
     connectUrl=None,  # type: Optional[String]
     username=None,  # type: Optional[String]
     password=None,  # type: Optional[String]
     props=None,  # type: Optional[String]
     validationQuery=None,  # type: Optional[String]
-    maxConnections=8,  # type: Optional[int]
+    maxConnections=8,  # type: int
 ):
     # type: (...) -> None
     """Adds a new database connection in Ignition.
@@ -116,7 +158,7 @@ def addDatasource(
     Args:
         jdbcDriver: The name of the JDBC driver configuration to use.
             Available options are based off the JDBC driver
-            configurations on the the Gateway.
+            configurations on the Gateway.
         name: The datasource name.
         description: Description of the datasource. Optional.
         connectUrl: Default is the connect URL for JDBC driver.
@@ -299,9 +341,9 @@ def commitTransaction(tx):
 
 def createSProcCall(
     procedureName,  # type: String
-    database="",  # type: Optional[String]
+    database="",  # type: String
     tx=None,  # type: Optional[String]
-    skipAudit=False,  # type: Optional[bool]
+    skipAudit=False,  # type: bool
 ):
     # type: (...) -> SProcCall
     """Creates an SProcCall object, which is a stored procedure call
@@ -483,7 +525,7 @@ def runNamedQuery(*args):
 def runPrepQuery(
     query,  # type: String
     args,  # type: List[Any]
-    database="",  # type: Optional[String]
+    database="",  # type: String
     tx=None,  # type: Optional[String]
 ):
     # type: (...) -> PyDataSet
@@ -516,7 +558,7 @@ def runPrepQuery(
             statement with placeholders (?) denoting where the arguments
             go.
         args: A list of arguments. Will be used in order to match each
-            each placeholder (?) found in the query.
+            placeholder (?) found in the query.
         database: The name of the database connection to execute
             against. If omitted or "", the project's default database
             connection will be used.
@@ -533,10 +575,10 @@ def runPrepQuery(
 def runPrepUpdate(
     query,  # type: String
     args,  # type: List[Any]
-    database="",  # type: Optional[String]
+    database="",  # type: String
     tx=None,  # type: Optional[String]
-    getKey=False,  # type: Optional[bool]
-    skipAudit=True,  # type: Optional[bool]
+    getKey=False,  # type: bool
+    skipAudit=True,  # type: bool
 ):
     # type: (...) -> int
     """Runs a prepared statement against the database, returning the
@@ -682,7 +724,7 @@ def runSFUpdateQuery(query, datasources):
 def runScalarPrepQuery(
     query,  # type: String
     args,  # type: List[Any]
-    database="",  # type: Optional[String]
+    database="",  # type: String
     tx=None,  # type: Optional[String]
 ):
     # type: (...) -> Any
@@ -739,10 +781,10 @@ def runScalarQuery(query, database="", tx=None):
 
 def runUpdateQuery(
     query,  # type: String
-    database="",  # type: Optional[String]
+    database="",  # type: String
     tx=None,  # type: Optional[String]
-    getKey=False,  # type: Optional[bool]
-    skipAudit=True,  # type: Optional[bool]
+    getKey=False,  # type: bool
+    skipAudit=True,  # type: bool
 ):
     # type: (...) -> int
     """Runs a query against a database connection, returning the number
