@@ -21,11 +21,10 @@ __all__ = [
 
 import socket
 
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional
 
 from com.inductiveautomation.ignition.common.script.builtin.http import JythonHttpClient
-
-String = Union[str, unicode]
+from java.lang import String
 
 
 def getExternalIpAddress():
@@ -94,13 +93,14 @@ def getRemoteServers(runningOnly=True):
 
 
 def httpClient(
-    timeout=60000,  # type: Optional[int]
-    bypass_cert_validation=False,  # type: Optional[bool]
+    timeout=60000,  # type: int
+    bypass_cert_validation=False,  # type: bool
     username=None,  # type: Optional[String]
     password=None,  # type: Optional[String]
     proxy=None,  # type: Optional[String]
-    cookie_policy="ACCEPT_ORIGINAL_SERVER",  # type: Optional[String]
-    redirect_policy="NORMAL",  # type: Optional[String]
+    cookie_policy="ACCEPT_ORIGINAL_SERVER",  # type: String
+    redirect_policy="NORMAL",  # type: String
+    version="HTTP_2",  # type: String
     customizer=None,  # type: Optional[Callable[..., Any]]
 ):
     # type: (...) -> JythonHttpClient
@@ -139,6 +139,9 @@ def httpClient(
         redirect_policy: A string representing this client's redirect
             policy. Acceptable values are listed below. Defaults to
             "Normal". Optional.
+        version: A string specifying either HTTP_2 or HTTP_1_1 for the
+            HTTP protocol. When omitted, the previous default of HTTP_2
+            is implied. Optional.
         customizer: A reference to a function. This function will be
             called with one argument (an instance of
             HttpClient.Builder). The function should operate on that
@@ -158,6 +161,7 @@ def httpClient(
         proxy,
         cookie_policy,
         redirect_policy,
+        version,
         customizer,
     )
     return JythonHttpClient()
@@ -166,12 +170,12 @@ def httpClient(
 def httpDelete(
     url,  # type: String
     contentType=None,  # type: Optional[String]
-    connectTimeout=10000,  # type: Optional[int]
-    readTimeout=60000,  # type: Optional[int]
+    connectTimeout=10000,  # type: int
+    readTimeout=60000,  # type: int
     username=None,  # type: Optional[String]
     password=None,  # type: Optional[String]
     headerValues=None,  # type: Optional[Dict[String, String]]
-    bypassCertValidation=True,  # type: Optional[bool]
+    bypassCertValidation=True,  # type: bool
 ):
     # type: (...) -> String
     """Performs an HTTP DELETE to the given URL.
@@ -213,14 +217,14 @@ def httpDelete(
 
 def httpGet(
     url,  # type: String
-    connectTimeout=10000,  # type: Optional[int]
-    readTimeout=60000,  # type: Optional[int]
+    connectTimeout=10000,  # type: int
+    readTimeout=60000,  # type: int
     username=None,  # type: Optional[String]
     password=None,  # type: Optional[String]
     headerValues=None,  # type: Optional[Dict[String, String]]
     bypassCertValidation=None,  # type: Optional[bool]
-    useCaches=True,  # type: Optional[bool]
-    throwOnError=True,  # type: Optional[bool]
+    useCaches=True,  # type: bool
+    throwOnError=True,  # type: bool
 ):
     # type: (...) -> String
     """Retrieves the document at the given URL using the HTTP GET
@@ -332,20 +336,20 @@ def openURL(url, useApplet=False):
 def sendEmail(
     smtp,  # type: String
     fromAddr,  # type: String
-    subject,  # type: String
-    body,  # type: String
-    html,  # type: String
-    to,  # type: List[String]
+    subject=None,  # type: Optional[String]
+    body=None,  # type: Optional[String]
+    html=False,  # type: bool
+    to=None,  # type: Optional[List[String]]
     attachmentNames=None,  # type: Optional[List[object]]
     attachmentData=None,  # type: Optional[List[object]]
-    timeout=300000,  # type: Optional[int]
+    timeout=300000,  # type: int
     username=None,  # type: Optional[String]
     password=None,  # type: Optional[String]
-    priority="3",  # type: Optional[String]
+    priority="3",  # type: String
     smtpProfile=None,  # type: Optional[String]
     cc=None,  # type: Optional[List[String]]
     bcc=None,  # type: Optional[List[String]]
-    retries=0,  # type: Optional[int]
+    retries=0,  # type: int
     replyTo=None,  # type: Optional[List[String]]
 ):
     # type: (...) -> None
@@ -360,10 +364,10 @@ def sendEmail(
             "mail.example.com:25". SSL can also be forced, like
             "mail.example.com:25:tls".
         fromAddr: An email address to have the email come from.
-        subject: The subject line for the email.
-        body: The body text of the email.
+        subject: The subject line for the email. Optional.
+        body: The body text of the email. Optional.
         html: A flag indicating whether or not to send the email as an
-            HTML email. Will auto-detect if omitted.
+            HTML email. Will auto-detect if omitted. Optional.
         to: A list of email addresses to send to.
         attachmentNames: A list of attachment names. Attachment names
             must have the correct extension for the file type or an
