@@ -7,7 +7,9 @@ Perspective Session from a Python script.
 from __future__ import print_function
 
 __all__ = [
+    "alterDock",
     "alterLogging",
+    "authenticationChallenge",
     "closeDock",
     "closePage",
     "closePopup",
@@ -34,19 +36,45 @@ __all__ = [
 
 import __builtin__ as builtins
 
-from typing import Any, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional
 
+from com.inductiveautomation.ignition.common.gson import JsonObject
 from com.inductiveautomation.ignition.common.script.adapters import PyJsonObjectAdapter
+from java.lang import String
 
-String = Union[str, unicode]
+
+def alterDock(
+    dockId,  # type: String
+    config=None,  # type: Optional[Dict[String, Any]]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+):
+    # type: (...) -> None
+    """Changes configuration of a specified dock on a Perspective Page.
+
+    Args:
+        dockId: The ID of the dock to be altered. If no such dock exists
+            on the current page with the given ID, a warning will be
+            logged to the console.
+        config: The new configuration for the dock. All properties are
+            optional, and any properties not specified will remain
+            unchanged. Optional.
+        sessionId: Identifier of the Session to target. If omitted, the
+            current Session will be used automatically. When targeting a
+            different Session, then the pageId parameter must be
+            included in the call. Optional.
+        pageId: Identifier of the Page to target. If omitted, the
+            current Page will be used automatically. Optional.
+    """
+    builtins.print(dockId, config, sessionId, pageId)
 
 
 def alterLogging(
-    remoteLoggingEnabled=False,  # type: Optional[bool]
-    level="info",  # type: Optional[String]
-    remoteLoggingLevel="warn",  # type: Optional[String]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
+    remoteLoggingEnabled=False,  # type: bool
+    level="info",  # type: String
+    remoteLoggingLevel="warn",  # type: String
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
 ):
     # type: (...) -> None
     """Changes Perspective Session logging attributes and levels.
@@ -57,7 +85,7 @@ def alterLogging(
     Args:
         remoteLoggingEnabled: Will enable remote logging if True. Remote
             logging will send log events from the Session to the Gateway
-            under the perspective.client logger if the meet the
+            under the `perspective.client` logger if they meet the
             remoteLevel logging level requirement. Optional.
         level: The desired Session logging level. Possible values are:
             all, trace, debug, info, warn, error, fatal, off. The
@@ -75,8 +103,58 @@ def alterLogging(
     builtins.print(remoteLoggingEnabled, level, remoteLoggingLevel, sessionId, pageId)
 
 
+def authenticationChallenge(
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+    idp="",  # type: String
+    forceAuth=False,  # type: bool
+    timeout=2,  # type: int
+    payload=None,  # type: Optional[Dict[String, Any]]
+    framing="self",  # type: String
+):
+    # type: (...) -> None
+    """Triggers an authentication challenge action.
+
+    Args:
+        sessionId: Identifier of the Session to target. If omitted, the
+            current Session will be used automatically. When targeting a
+            different session, then the pageId parameter must be
+            included in the call. Optional.
+        pageId: Identifier of the page to target. If omitted, the
+            current page will be used. Optional.
+        idp: The name of the IdP to use for this authentication
+            challenge. If omitted, the Project default IdP will be used.
+            Optional.
+        forceAuth: True if Ignition should ask the IdP to
+            re-authenticate the user, even if the user is already signed
+            into the IdP. False if Ignition should not ask the IdP to
+            re-authenticate the user. If the IdP supports this option,
+            the IdP will ask the user to re-enter their credentials,
+            even if the user is already signed into the IdP. If omitted,
+            the default value for this argument will fall back to the
+            value in the Project Properties. Optional.
+        timeout: The number of minutes the system will wait in between
+            the authentication request and the authentication response
+            before timing out the request. If set to any number <= zero,
+            the request is rejected. If omitted, the default of two
+            minutes will be used as the timeout. Optional.
+        payload: An opaque payload object that may contain any
+            information. This object will be passed to the
+            onAuthenticationChallengeCompleted session event script. The
+            payload should be a JSON-encodable data structure.
+            Optional.
+        framing: A string representing the type of framing that should
+            be used. A value of "self" indicates that the same window
+            should be used. A value of "new" indicates that a new tab
+            should be used. A value of "embedded" indicates that an
+            embedded iframe should be used. If omitted, the default
+            value of "self" (same window) is used. Optional.
+    """
+    builtins.print(sessionId, pageId, idp, forceAuth, timeout, payload, framing)
+
+
 def closeDock(id, sessionId="current_session", pageId="current_page"):
-    # type: (String, Optional[String], Optional[String]) -> None
+    # type: (String, String, String) -> None
     """Closes a docked view.
 
     Args:
@@ -95,8 +173,8 @@ def closeDock(id, sessionId="current_session", pageId="current_page"):
 
 def closePage(
     message=None,  # type: Optional[String]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
 ):
     # type: (...) -> None
     """Closes the page with the given page id or the current page if no
@@ -121,12 +199,12 @@ def closePage(
 
 
 def closePopup(id, sessionId="current_session", pageId="current_page"):
-    # type: (String, Optional[String], Optional[String]) -> None
+    # type: (String, String, String) -> None
     """Closes a popup View.
 
     Args:
-        id: The unique identifier for the the popup, given to the popup
-            when first opened. If given an empty string, then the most
+        id: The unique identifier for the popup, given to the popup when
+            first opened. If given an empty string, then the most
             recently focused popup will be closed.
         sessionId: Identifier of the Session to target. If omitted, the
             current Session will be used automatically. When targeting a
@@ -139,12 +217,12 @@ def closePopup(id, sessionId="current_session", pageId="current_page"):
 
 
 def closeSession(message=None, sessionId="current_session"):
-    # type: (Optional[String], Optional[String]) -> None
+    # type: (Optional[String], String) -> None
     """Closes the Perspective Session with the given Session ID or the
     current Session if no ID is provided.
 
     If a message is provided, it is displayed on the page when the
-    Session closes. Otherwise the default message (set in the Project
+    Session closes. Otherwise, the default message (set in the Project
     Properties) is displayed.
 
     Args:
@@ -161,8 +239,8 @@ def download(
     filename,  # type: String
     data,  # type: Any
     contentType=None,  # type: Optional[String]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
 ):
     # type: (...) -> None
     """Downloads data from the gateway to a device running a Session.
@@ -214,18 +292,18 @@ def getSessionInfo(
     Gateway, and some Session props (id and userAgent).
 
     Args:
-        usernameFilter: A filter based on logged in user. Optional.
+        usernameFilter: A filter based on logged-in user. Optional.
         projectFilter: A filter based on the project name. Optional.
 
     Returns:
         A list of objects (PyJsonObjectAdapter).
     """
     builtins.print(usernameFilter, projectFilter)
-    return [PyJsonObjectAdapter(None)]
+    return [PyJsonObjectAdapter(JsonObject())]
 
 
 def isAuthorized(isAllOf, securityLevels, sessionId="current_session"):
-    # type: (bool, List[String], Optional[String]) -> bool
+    # type: (bool, List[String], String) -> bool
     """Checks if the user in the current Session is authorized against a
     target collection of security levels.
 
@@ -250,7 +328,7 @@ def isAuthorized(isAllOf, securityLevels, sessionId="current_session"):
 
 
 def login(sessionId="current_session", pageId="current_page", forceAuth=False):
-    # type: (Optional[String], Optional[String], Optional[bool]) -> None
+    # type: (String, String, bool) -> None
     """Triggers a login event that will allow the user to login with the
     project's configured Identity Provider (IdP).
 
@@ -284,9 +362,9 @@ def login(sessionId="current_session", pageId="current_page", forceAuth=False):
 
 
 def logout(
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
-    message="default message",  # type: Optional[String]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+    message="default message",  # type: String
 ):
     # type: (...) -> None
     """Triggers a logout event, which will log the user out.
@@ -314,9 +392,9 @@ def navigate(
     url=None,  # type: Optional[String]
     view=None,  # type: Optional[String]
     params=None,  # type: Optional[Dict[String, String]]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
-    newTab=False,  # type: Optional[bool]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+    newTab=False,  # type: bool
 ):
     # type: (...) -> None
     """Navigate the Session to a specified view or mounted page.
@@ -359,7 +437,7 @@ def navigate(
 
 
 def navigateBack(sessionId="current_session", pageId="current_page"):
-    # type: (Optional[String], Optional[String]) -> None
+    # type: (String, String) -> None
     """Navigate the Session to a specified view or mounted page.
 
     This is similar to a browser's "back" function.
@@ -374,7 +452,7 @@ def navigateBack(sessionId="current_session", pageId="current_page"):
 
 
 def navigateForward(sessionId="current_session", pageId="current_page"):
-    # type: (Optional[String], Optional[String]) -> None
+    # type: (String, String) -> None
     """Navigate the Session to a specified view or mounted page.
 
     This is similar to a browser's "forward" function.
@@ -392,8 +470,8 @@ def navigateForward(sessionId="current_session", pageId="current_page"):
 
 def openDock(
     id,  # type: String
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
     params=None,  # type: Optional[Dict[String, String]]
 ):
     # type: (...) -> None
@@ -421,16 +499,16 @@ def openPopup(
     id,  # type: String
     view,  # type: String
     params=None,  # type: Optional[Dict[String, Any]]
-    title="",  # type: Optional[String]
+    title="",  # type: String
     position=None,  # type: Optional[Dict[String, int]]
-    showCloseIcon=True,  # type: Optional[bool]
-    draggable=True,  # type: Optional[bool]
-    resizable=False,  # type: Optional[bool]
-    modal=False,  # type: Optional[bool]
-    overlayDismiss=False,  # type: Optional[bool]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
-    viewPortBound=False,  # type: Optional[bool]
+    showCloseIcon=True,  # type: bool
+    draggable=True,  # type: bool
+    resizable=False,  # type: bool
+    modal=False,  # type: bool
+    overlayDismiss=False,  # type: bool
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+    viewPortBound=False,  # type: bool
 ):
     # type: (...) -> None
     """Open a popup view over the given page.
@@ -489,9 +567,9 @@ def openPopup(
 
 def print(
     message,  # type: String
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
-    destination="client",  # type: Optional[String]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+    destination="client",  # type: String
 ):
     # type: (...) -> None
     """Sends print statements to the scripting console when in the
@@ -539,9 +617,9 @@ def refresh(sessionId="current_session", pageId="current_page"):
 def sendMessage(
     messageType,  # type: String
     payload,  # type: Dict[String, String]
-    scope="page",  # type: Optional[String]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
+    scope="page",  # type: String
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
 ):
     # type: (...) -> None
     """Send a message to a message handler within the same Session.
@@ -588,8 +666,8 @@ def setTheme(name, sessionId="current_session", pageId="current_page"):
 
 def toggleDock(
     id,  # type: String
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
     params=None,  # type: Optional[Dict[String, String]]
 ):
     # type: (...) -> None
@@ -615,16 +693,16 @@ def togglePopup(
     id,  # type: String
     view,  # type: String
     params,  # type: Optional[Dict[String, Any]]
-    title="",  # type: Optional[String]
+    title="",  # type: String
     position=None,  # type: Optional[Dict[String, int]]
-    showCloseIcon=True,  # type: Optional[bool]
-    draggable=True,  # type: Optional[bool]
-    resizable=False,  # type: Optional[bool]
-    modal=False,  # type: Optional[bool]
-    overlayDismiss=False,  # type: Optional[bool]
-    sessionId="current_session",  # type: Optional[String]
-    pageId="current_page",  # type: Optional[String]
-    viewPortBound=False,  # type: Optional[bool]
+    showCloseIcon=True,  # type: bool
+    draggable=True,  # type: bool
+    resizable=False,  # type: bool
+    modal=False,  # type: bool
+    overlayDismiss=False,  # type: bool
+    sessionId="current_session",  # type: String
+    pageId="current_page",  # type: String
+    viewPortBound=False,  # type: bool
 ):
     # type: (...) -> None
     """Toggles a popup view.
