@@ -7,6 +7,42 @@ ports.
 from __future__ import print_function
 
 __all__ = [
+    "BIT_RATE_110",
+    "BIT_RATE_115200",
+    "BIT_RATE_1200",
+    "BIT_RATE_150",
+    "BIT_RATE_19200",
+    "BIT_RATE_230400",
+    "BIT_RATE_2400",
+    "BIT_RATE_300",
+    "BIT_RATE_38400",
+    "BIT_RATE_460800",
+    "BIT_RATE_4800",
+    "BIT_RATE_57600",
+    "BIT_RATE_600",
+    "BIT_RATE_921600",
+    "BIT_RATE_9600",
+    "DATA_BITS_5",
+    "DATA_BITS_6",
+    "DATA_BITS_7",
+    "DATA_BITS_8",
+    "HANDSHAKE_CTS_DTR",
+    "HANDSHAKE_CTS_RTS",
+    "HANDSHAKE_DSR_DTR",
+    "HANDSHAKE_HARD_IN",
+    "HANDSHAKE_HARD_OUT",
+    "HANDSHAKE_NONE",
+    "HANDSHAKE_SOFT_IN",
+    "HANDSHAKE_SOFT_OUT",
+    "HANDSHAKE_SPLIT_MASK",
+    "HANDSHAKE_XON_XOFF",
+    "PARITY_EVEN",
+    "PARITY_MARK",
+    "PARITY_NONE",
+    "PARITY_ODD",
+    "PARITY_SPACE",
+    "STOP_BITS_1",
+    "STOP_BITS_2",
     "closeSerialPort",
     "configureSerialPort",
     "openSerialPort",
@@ -20,13 +56,14 @@ __all__ = [
     "writeBytes",
 ]
 
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional
 
 from com.inductiveautomation.ignition.modules.serial.scripting import SerialScriptModule
+from java.lang import String
 
 PortManager = SerialScriptModule.PortManager
 SerialConfigurator = SerialScriptModule.SerialConfigurator
-String = Union[str, unicode]
+
 
 # Bit rate constants.
 BIT_RATE_110 = 110
@@ -249,8 +286,8 @@ def readBytes(port, numberOfBytes, timeout=5000):
 def readBytesAsString(
     port,  # type: String
     numberOfBytes,  # type: int
-    timeout=5000,  # type: Optional[int]
-    encoding="utf-8",  # type: Optional[String]
+    timeout=5000,  # type: int
+    encoding="utf-8",  # type: String
 ):
     # type: (...) -> String
     """Read numberOfBytes bytes from a serial port and convert them to a
@@ -277,9 +314,9 @@ def readBytesAsString(
 
 def readLine(
     port,  # type: String
-    timeout=5000,  # type: Optional[int]
-    encoding="utf-8",  # type: Optional[String]
-    crlfRequired=False,  # type: Optional[bool]
+    timeout=5000,  # type: int
+    encoding="utf-8",  # type: String
+    crlfRequired=False,  # type: bool
 ):
     # type: (...) -> String
     r"""Attempts to read a line from a serial port.
