@@ -66,24 +66,23 @@ from com.inductiveautomation.ignition.common.script.builtin import (
 )
 from com.inductiveautomation.ignition.common.util import LoggerEx
 from java.awt import Toolkit
-from java.lang import Thread
+from java.lang import String, Thread
 from java.util import Date
 
 PyDataSet = DatasetUtilities.PyDataSet
 RequestImpl = SystemUtilities.RequestImpl
-String = Union[str, unicode]
 
 
 def audit(
     action=None,  # type: Optional[String]
     actionValue=None,  # type: Optional[String]
-    auditProfile="",  # type: Optional[String]
+    auditProfile="",  # type: String
     actor=None,  # type: Optional[String]
-    actorHost="localhost",  # type: Optional[String]
+    actorHost="localhost",  # type: String
     originatingSystem=None,  # type: Optional[List[String]]
     eventTimestamp=None,  # type: Optional[Date]
-    originatingContext=4,  # type: Optional[int]
-    statusCode=0,  # type: Optional[int]
+    originatingContext=4,  # type: int
+    statusCode=0,  # type: int
 ):
     # type: (...) -> None
     """Inserts a record into an audit profile.
@@ -150,7 +149,7 @@ def execute(commands):
 
 
 def exit(force=False):
-    # type: (Optional[bool]) -> None
+    # type: (bool) -> None
     """Exits the running client, as long as the shutdown intercept
     script doesn't cancel the shutdown event.
 
@@ -201,7 +200,7 @@ def getClientId():
         A special code representing the Client's Session in a unique
         way.
     """
-    return u"F6D410AC"
+    return unicode("F6D410AC")
 
 
 def getConnectTimeout():
@@ -252,14 +251,14 @@ def getGatewayAddress():
         The address of the Gateway that the client is communicating
         with.
     """
-    return u"http://localhost:8088/"
+    return unicode("http://localhost:8088/")
 
 
 def getGatewayStatus(
     gatewayAddress,  # type: String
     connectTimeoutMillis=None,  # type: Optional[int]
     socketTimeoutMillis=None,  # type: Optional[int]
-    bypassCertValidation=True,  # type: Optional[bool]
+    bypassCertValidation=True,  # type: bool
 ):
     # type: (...) -> unicode
     """Returns a string that indicates the status of the Gateway.
@@ -288,7 +287,7 @@ def getGatewayStatus(
     print(
         gatewayAddress, connectTimeoutMillis, socketTimeoutMillis, bypassCertValidation
     )
-    return u"RUNNING"
+    return unicode("RUNNING")
 
 
 def getGlobals():
@@ -478,7 +477,7 @@ def getVersion():
 
 
 def invokeAsynchronous(
-    function,  # type: Callable
+    function,  # type: Callable[..., Any]
     args=None,  # type: Optional[Iterable[Any]]
     kwargs=None,  # type: Optional[Dict[String, Any]]
     description=None,  # type: Optional[String]
@@ -517,7 +516,7 @@ def invokeAsynchronous(
 
 
 def invokeLater(function, delay=0):
-    # type: (Callable[..., Any], Optional[int]) -> None
+    # type: (Callable[..., Any], int) -> None
     """Invokes (calls) the given Python function object after all of the
     currently processing and pending events are done being processed,
     or after a specified delay.
@@ -557,7 +556,7 @@ def jsonDecode(jsonString):
 
 
 def jsonEncode(pyObj, indentFactor=4):
-    # type: (Iterable[Any], Optional[int]) -> String
+    # type: (Iterable[Any], int) -> String
     """Takes a Python object such as a list or dict and converts into a
     JSON string.
 
@@ -574,7 +573,7 @@ def jsonEncode(pyObj, indentFactor=4):
 
 
 def modifyTranslation(term, translation, locale="es_MX"):
-    # type: (String, String, Optional[String]) -> None
+    # type: (String, String, String) -> None
     """This function allows you to add or modify a global translation.
 
     Args:
@@ -588,7 +587,7 @@ def modifyTranslation(term, translation, locale="es_MX"):
 
 
 def playSoundClip(wav, volume=1.0, wait=False):
-    # type: (Any, Optional[float], Optional[bool]) -> None
+    # type: (Any, float, bool) -> None
     """Plays a sound clip from a wav file to the system's default audio
     device.
 
@@ -970,7 +969,7 @@ def threadDump():
     Returns:
         The dump of the current running JVM.
     """
-    return u"""{0}\n  "version": "{1}"...{2}""".format(
+    return unicode("""{0}\n  "version": "{1}"...{2}""").format(
         "{", getVersion().toParseableString(), "}"
     )
 
